/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.streaming.connectors.kafka.partitioner;

import org.apache.flink.annotation.PublicEvolving;
import org.apache.flink.connector.kafka.sink.KafkaPartitioner;

/**
 * A {@link FlinkKafkaPartitioner} wraps logic on how to partition records across partitions of
 * multiple Kafka topics.
 *
 * @deprecated Use {@link KafkaPartitioner} instead for {@link
 *     org.apache.flink.connector.kafka.sink.KafkaSink}.
 */
@PublicEvolving
@Deprecated
public abstract class FlinkKafkaPartitioner<T> implements KafkaPartitioner<T> {

    private static final long serialVersionUID = -9086719227828020494L;
}
